.. _licensing_policy:

================
Licensing Policy
================

Our vision
==========

The goal of openEPDA is to facilitate data exchange between the tools and
parties involved in the PIC design. This is done by standardizing the
data exchange in the field of Electronic-Photonic Design Automation (EPDA),
which improves tool interoperability and traceability of data. Essentially,
openEPDA consists of two parts: standard specifications and a reference
implementation.

In order to fulfil our main goal, the provided standards
are open, accessible to anyone and royalty-free. Our vision coincides
with that of the Free Software Foundation Europe on
`open standards <https://fsfe.org/activities/os/os.en.html>`_.

In the `python package <https://pypi.org/project/openepda/>`_, we aim
to provide validators for the data files and reference implementations
of the data readers/writers. Validation is done using
`JSON Schema <https://json-schema.org/>`_ and custom code on top of it
when needed.

The name openEPDA is trademarked. This is done to ensure that the name
cannot be misused and that the data under this name is compliant with the
published standards.

License terms
=============
The openEPDA standards specification can be freely used and
distributed in its original form under the CC BY-ND 4.0 license. It allows
free use of the standards, including for commercial purposes, such as:

- (de-)serialization of data represented with the openEPDA formats;
- creation of readers / writers / converters to and from the openEPDA formats.

When using the openEPDA data formats, credit to openEDPA.org must be provided.

The license does not allow others to modify the content of the
openEPDA standard specifications if they are to be redistributed.

More on the license can be found at `<https://creativecommons.org/licenses/>`_.

Governance body
===============

After the first standard drafts are finalized, we will set up a
governance body with stakeholders. This will ensure the standards
development and evolution.
